@@ -1,7 +1,6 @@
 # coding=utf-8
 import logging
 import re
-from requests.exceptions import HTTPError
 from .rest_client import AtlassianRestAPI
 
 log = logging.getLogger(__name__)
@@ -904,26 +903,28 @@ class Jira(AtlassianRestAPI):
         return self.delete(url, params=params)
 
     def issue_exists(self, issue_key):
+        original_value = self.advanced_mode
+        self.advanced_mode = True
         try:
-            self.issue(issue_key, fields='*none')
+            resp = self.issue(issue_key, fields="*none")
+            if resp.status_code == 404:
+                log.info(
+                    'Issue "{issue_key}" does not exists'.format(issue_key=issue_key)
+                )
+                return False
+            resp.raise_for_status()
             log.info('Issue "{issue_key}" exists'.format(issue_key=issue_key))
             return True
-        except HTTPError as e:
-            if e.response.status_code == 404:
-                log.info('Issue "{issue_key}" does not exists'.format(issue_key=issue_key))
-                return False
-            else:
-                log.info('Issue "{issue_key}" existed, but now it\'s deleted'.format(issue_key=issue_key))
-                return True
+        finally:
+            self.advanced_mode = original_value
 
     def issue_deleted(self, issue_key):
-        try:
-            self.issue(issue_key, fields='*none')
+        exists = self.issue_exists(issue_key)
+        if exists:
             log.info('Issue "{issue_key}" is not deleted'.format(issue_key=issue_key))
-            return False
-        except HTTPError:
+        else:
             log.info('Issue "{issue_key}" is deleted'.format(issue_key=issue_key))
-            return True
+        return not exists
 
     def delete_issue(self, issue_id_or_key, delete_subtasks=True):
         """
@@ -2438,7 +2439,8 @@ class Jira(AtlassianRestAPI):
         A sprint can be started by updating the state to 'active'.
         This requires the sprint to be in the 'future' state and have a startDate and endDate set.
         A sprint can be completed by updating the state to 'closed'.
-        This action requires the sprint to be in the 'active' state. This sets the completeDate to the time of the request.
+        This action requires the sprint to be in the 'active' state.
+        This sets the completeDate to the time of the request.
         Other changes to state are not allowed.
         The completeDate field cannot be updated manually.
         :param sprint_id:
@@ -2507,10 +2509,10 @@ class Jira(AtlassianRestAPI):
                       it will be set do default value: 1000)
         :param filter:	string = text query; each record that will be returned
                         must contain the provided text in one of its fields
-        :param from: string	 - timestamp in past; 'from' must be less or equal 'to',
+        :param from_date: string	 - timestamp in past; 'from' must be less or equal 'to',
                              otherwise the result set will be empty only records that
                              where created in the same moment or after the 'from' timestamp will be provided in response
-        :param to: string	- timestamp in past; 'from' must be less or equal 'to',
+        :param to_date: string	- timestamp in past; 'from' must be less or equal 'to',
                               otherwise the result set will be empty only records that
                               where created in the same moment or earlier than the 'to'
                               timestamp will be provided in response
@@ -2537,4 +2539,4 @@ class Jira(AtlassianRestAPI):
         :return:
         """
         url = "rest/api/2/auditing/record"
-        return self.post(url, data=audit_record)
\ No newline at end of file
+        return self.post(url, data=audit_record)
